@@ -1,19 +1,18 @@
-import simplejson as json
 import os
 from typing import List, Literal, Tuple, Union
 
 import numpy as np
+import simplejson as json
 
 from worker.data import math
 from worker.data.api import API
-from worker.data.enums import Environment, EventTypes
+from worker.data.enums import Environment, EventType
 from worker.data.wits import WITS
 from worker.exceptions import NotFound
 
 
 def gather_data_for_period(
-        asset_id: int, start: int, end: int, limit: int = 1800,
-        collection: str = "wits", fields: str = None
+    asset_id: int, start: int, end: int, limit: int = 1800, collection: str = "wits", fields: str = None
 ) -> list:
     """
     Get the wits data from API for an asset over an interval
@@ -28,12 +27,18 @@ def gather_data_for_period(
     if start >= end:
         return []
 
-    query = '{timestamp#gte#%s}AND{timestamp#lte#%s}' % (start, end)
+    query = "{timestamp#gte#%s}AND{timestamp#lte#%s}" % (start, end)
     worker = API()
 
     wits_dataset = worker.get(
-        path="/v1/data/corva", collection=collection, asset_id=asset_id, sort="{timestamp: 1}", limit=limit,
-        query=query, fields=fields).data
+        path="/v1/data/corva",
+        collection=collection,
+        asset_id=asset_id,
+        sort="{timestamp: 1}",
+        limit=limit,
+        query=query,
+        fields=fields,
+    ).data
 
     if not wits_dataset:
         return []
@@ -50,8 +55,14 @@ def get_one_data_record(asset_id: int, timestamp_sort: int = -1, collection: str
     :return:
     """
     api_worker = API()
-    data = api_worker.get(path='/v1/data/corva/', collection=collection, asset_id=asset_id,
-                          sort="{timestamp:%s}" % timestamp_sort, limit=1).data
+    data = api_worker.get(
+        path="/v1/data/corva/",
+        collection=collection,
+        asset_id=asset_id,
+        sort="{timestamp:%s}" % timestamp_sort,
+        limit=1,
+    ).data
+
     if not data:
         return {}
 
@@ -85,7 +96,7 @@ def delete_collection_data_of_asset_id(asset_id: int, collections: Union[str, li
                 break
 
 
-def point_main_envs(env: Literal['qa', 'staging', 'production', 'local']):
+def point_main_envs(env: Literal["qa", "staging", "production", "local"]):
     """
     The purpose of this function is to point main environment variables to
     the provided environment. This method updates the following environment
@@ -110,16 +121,12 @@ def point_main_envs(env: Literal['qa', 'staging', 'production', 'local']):
     if not all([api_url, api_key, cache_url]):
         raise ValueError("Missing environment variables!")
 
-    new_envs = {
-        'API_ROOT_URL': api_url,
-        'API_KEY': api_key,
-        'CACHE_URL': cache_url
-    }
+    new_envs = {"API_ROOT_URL": api_url, "API_KEY": api_key, "CACHE_URL": cache_url}
 
     os.environ.update(new_envs)
 
 
-def setup_api_worker(env: Literal['qa', 'staging', 'production', 'local'], app_name: str) -> API:
+def setup_api_worker(env: Literal["qa", "staging", "production", "local"], app_name: str) -> API:
     """
     Set up the Corva API worker
     :param env: environment ['local', 'qa', 'staging', 'production']
@@ -132,17 +139,13 @@ def setup_api_worker(env: Literal['qa', 'staging', 'production', 'local'], app_n
     api_url = os.getenv(f"API_ROOT_URL_{env}") or os.getenv("API_ROOT_URL")
     api_key = os.getenv(f"API_KEY_{env}") or os.getenv("API_KEY")
 
-    options = {
-        "api_url": api_url,
-        "api_key": api_key,
-        "app_name": app_name
-    }
+    options = {"api_url": api_url, "api_key": api_key, "app_name": app_name}
     api_worker = API(**options)
 
     return api_worker
 
 
-def setup_redis_worker(env: Literal['qa', 'staging', 'production', 'local']):
+def setup_redis_worker(env: Literal["qa", "staging", "production", "local"]):
     """
     Set up the Redis worker
     :param env: environment ['local', 'qa', 'staging', 'production']
@@ -154,6 +157,7 @@ def setup_redis_worker(env: Literal['qa', 'staging', 'production', 'local']):
     cache_url = os.getenv(f"CACHE_URL_{env}") or os.getenv("CACHE_URL")
 
     import redis
+
     redis_worker = redis.Redis.from_url(cache_url, decode_responses=True)
 
     return redis_worker
@@ -168,9 +172,7 @@ def get_config_by_id(string_id: str, collection: str) -> Union[dict, None]:
     """
     string = None
     try:
-        string = API().get_by_id(
-            path="/v1/data/corva/", collection=collection, id=string_id
-        ).data
+        string = API().get_by_id(path="/v1/data/corva/", collection=collection, id=string_id).data
     except NotFound:
         pass
 
@@ -286,8 +288,8 @@ def get_data_by_path(data: dict, path: str, func=lambda x: x, **kwargs):
     note that None is an acceptable default
     :return:
     """
-    has_default = 'default' in kwargs
-    default = kwargs.pop('default', None)
+    has_default = "default" in kwargs
+    default = kwargs.pop("default", None)
 
     if not path:
         if has_default:
@@ -295,7 +297,7 @@ def get_data_by_path(data: dict, path: str, func=lambda x: x, **kwargs):
 
         raise KeyError("No key provided")
 
-    keys = path.split('.')
+    keys = path.split(".")
 
     while keys:
         current_key = keys.pop(0)
@@ -304,7 +306,7 @@ def get_data_by_path(data: dict, path: str, func=lambda x: x, **kwargs):
             if has_default:
                 return default
 
-            raise KeyError("{0} not found in path".format(current_key))
+            raise KeyError(f"{current_key} not found in path")
 
         data = data.get(current_key)
 
@@ -366,7 +368,7 @@ def equal(obj1: object, obj2: object, params: List[str]) -> bool:
     return all(getattr(obj1, param) == getattr(obj2, param) for param in params)
 
 
-def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
+def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventType]:
     """
     validate and flatten the events and organize the data into a desired format
 
@@ -386,11 +388,14 @@ def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
         event = json.loads(event)
 
     if isinstance(event, dict):
+        if event.get("event_type") == "partial-well-rerun-merge":
+            return event, EventType.PARTIAL_RERUN
+
         if "asset_id" in event:
-            return event, EventTypes.GENERIC
+            return event, EventType.GENERIC
 
         if "task_id" in event:
-            return event, EventTypes.TASK
+            return event, EventType.TASK
 
         raise TypeError("Missing task_id or asset_id keys in event")
 
@@ -400,14 +405,14 @@ def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
     first_event = event[0]
     if isinstance(first_event, list):
         if first_event[0] and "schedule_start" in first_event[0]:
-            return event, EventTypes.SCHEDULER
+            return event, EventType.SCHEDULER
 
         raise Exception("Missing scheduler_start key in scheduler event")
 
     elif isinstance(first_event, dict):
         # new kafka stream format: list of json objects, each with metadata and records
         # event = [{"metadata": { ... }, "records": [ ... ]}, {"metadata": { ... }, "records": [ ... ]}]
-        return event, EventTypes.STREAM
+        return event, EventType.STREAM
 
     raise TypeError("Event is not either a scheduler or kafka consumer")
 
@@ -431,7 +436,7 @@ def compute_time_step(records: Union[List[WITS], List[dict], List[float]], perce
     if isinstance(records[0], WITS):
         timestamps = [rec.timestamp for rec in records]
     elif isinstance(records[0], dict):
-        timestamps = [rec.get('timestamp') for rec in records]
+        timestamps = [rec.get("timestamp") for rec in records]
     else:
         timestamps = records
 
