@@ -1,17 +1,16 @@
 import argparse
-import simplejson as json
 import os
 from functools import cached_property
 
+import simplejson as json
 from tqdm import tqdm
 
 from worker.data import operations
 from worker.data.json_encoder import JsonEncoder
 from worker.mixins.logging import LoggingMixin
 
-
-API_DATA_PATH = '/v1/data/corva/'
-API_ASSET_PATH = '/v1/assets/'
+API_DATA_PATH = "/v1/data/corva/"
+API_ASSET_PATH = "/v1/assets/"
 
 
 def generate_transfer_parser():
@@ -20,18 +19,51 @@ def generate_transfer_parser():
     :return:
     """
     parser = argparse.ArgumentParser(description="Run your tests locally on an asset.")
-    parser.add_argument("-v", "--source_environment", "--env", type=str, required=True,
-                        help="source environment, options: 'qa', 'staging', 'production'")
-    parser.add_argument("-a", "--source_asset_id", "--id", type=int, required=True,
-                        help="set source asset_id")
-    parser.add_argument("-s", "--start_timestamp", "--start", type=int, required=False, default=None,
-                        help="start timestamp for the main collections to be copied over")
-    parser.add_argument("-e", "--end_timestamp", "--end", type=int, required=False, default=None,
-                        help="end timestamp for the main collections to be copied over")
-    parser.add_argument("-c", "--config_collections", "--config", type=json.loads, required=False, default=None,
-                        help="setting a new config collection list that override the existing one")
-    parser.add_argument("-m", "--main_collections", "--main", type=json.loads, required=False, default=None,
-                        help="setting a new main collection list that override the existing one")
+    parser.add_argument(
+        "-v",
+        "--source_environment",
+        "--env",
+        type=str,
+        required=True,
+        help="source environment, options: 'qa', 'staging', 'production'",
+    )
+    parser.add_argument("-a", "--source_asset_id", "--id", type=int, required=True, help="set source asset_id")
+    parser.add_argument(
+        "-s",
+        "--start_timestamp",
+        "--start",
+        type=int,
+        required=False,
+        default=None,
+        help="start timestamp for the main collections to be copied over",
+    )
+    parser.add_argument(
+        "-e",
+        "--end_timestamp",
+        "--end",
+        type=int,
+        required=False,
+        default=None,
+        help="end timestamp for the main collections to be copied over",
+    )
+    parser.add_argument(
+        "-c",
+        "--config_collections",
+        "--config",
+        type=json.loads,
+        required=False,
+        default=None,
+        help="setting a new config collection list that override the existing one",
+    )
+    parser.add_argument(
+        "-m",
+        "--main_collections",
+        "--main",
+        type=json.loads,
+        required=False,
+        default=None,
+        help="setting a new main collection list that override the existing one",
+    )
     return parser
 
 
@@ -41,13 +73,11 @@ class ToLocalTransfer(LoggingMixin):
         "data.surface-equipment",
         "data.actual_survey",
         "data.plan_survey",
-
         # in the following collections the setting timestamps need to be removed
         # but for the purpose of this test analysis is not important.
         "data.casing",
         "data.drillstring",
         "data.mud"
-
         # not required for most of the cases
         # "data.formations",
         # "data.pressure-gradient",
@@ -57,9 +87,7 @@ class ToLocalTransfer(LoggingMixin):
     ]
 
     # collections other than configs: this can be modified in __init__
-    MAIN_COLLECTIONS = [
-        "wits"
-    ]
+    MAIN_COLLECTIONS = ["wits"]
 
     def __init__(self, args):
         super().__init__()
@@ -131,11 +159,11 @@ class ToLocalTransfer(LoggingMixin):
 
         well_properties = well_properties.data[0]
 
-        if well_properties['asset_type'] != 'well':
+        if well_properties["asset_type"] != "well":
             raise Exception("Not a well")
 
-        self.well_name = well_properties['name']
-        self.source_company_id = well_properties['company_id']
+        self.well_name = well_properties["name"]
+        self.source_company_id = well_properties["company_id"]
 
     def setup_local_well(self):
         """
@@ -150,7 +178,7 @@ class ToLocalTransfer(LoggingMixin):
         found = False
         if wells.count >= 1:
             well = wells.data[0]
-            well_name2 = well['name']
+            well_name2 = well["name"]
             if self.well_name == well_name2:
                 found = True
                 print("Found local asset!")
@@ -163,14 +191,14 @@ class ToLocalTransfer(LoggingMixin):
                 "company_id": 1,
                 "visibility": "visible",
                 "asset_type": "well",
-                "type": "Asset::Well"
+                "type": "Asset::Well",
             }
             data_json = json.dumps(data, cls=JsonEncoder, ignore_nan=True)
             well = self.local_api_worker.post(path=API_ASSET_PATH, data=data_json).data
             print("Well is created!")
 
         self.is_new_well = not found
-        self.local_asset_id = well['id']
+        self.local_asset_id = well["id"]
         print(f"Local asset_id={self.local_asset_id}")
 
     def store_config_data(self):
@@ -197,7 +225,7 @@ class ToLocalTransfer(LoggingMixin):
         count_records = 0
         for col in self.CONFIG_COLLECTIONS:
             records = []
-            print(f"{col:30} ", end='')
+            print(f"{col:30} ", end="")
             col_data = self.source_api_worker.get(
                 path=API_DATA_PATH, collection=col, asset_id=self.source_asset_id, limit=10000
             )
@@ -208,12 +236,12 @@ class ToLocalTransfer(LoggingMixin):
 
             records.extend(col_data.data)
 
-            source_ids = [record['_id'] for record in records]
+            source_ids = [record["_id"] for record in records]
 
             for record in records:
-                record['company_id'] = 1
-                record['asset_id'] = self.local_asset_id
-                record.pop('_id', None)
+                record["company_id"] = 1
+                record["asset_id"] = self.local_asset_id
+                record.pop("_id", None)
 
             # post
             results = self.local_api_worker.post(
@@ -221,11 +249,13 @@ class ToLocalTransfer(LoggingMixin):
             )
             print(f"{'successful':10} ", end="\n")
 
-            local_ids = results.data['ids']
+            local_ids = results.data["ids"]
             count_records += len(local_ids)
 
             if len(source_ids) != len(local_ids):
-                raise IndexError(f"Number of source ids ({len(source_ids)}) does not match local ids ({len(local_ids)})")
+                raise IndexError(
+                    f"Number of source ids ({len(source_ids)}) does not match local ids ({len(local_ids)})"
+                )
 
             collection_id_mapper = {source_ids[i]: local_ids[i] for i in range(len(source_ids))}
             config_id_mapper[col] = collection_id_mapper
@@ -273,13 +303,13 @@ class ToLocalTransfer(LoggingMixin):
                 path=API_DATA_PATH, collection=col, asset_id=self.local_asset_id, sort="{timestamp:-1}", limit=1
             )
             if res.count > 0:
-                ts = res.data[0].get('timestamp', 0)
+                ts = res.data[0].get("timestamp", 0)
             else:
                 ts = start_timestamp - 1
 
             print(f"'{col}' collection, Source Range: [{start_timestamp}, {end_timestamp}], Local Start: {ts}")
 
-            limit = 3600 if col == 'wits' else 100
+            limit = 3600 if col == "wits" else 100
 
             pbar = tqdm(total=100, ncols=100, disable=not show_progress)
 
@@ -288,8 +318,12 @@ class ToLocalTransfer(LoggingMixin):
                 query = "{timestamp#gt#%s}AND{timestamp#lte#%s}" % (ts, end_timestamp)
 
                 res = self.source_api_worker.get(
-                    path=API_DATA_PATH, collection=col, asset_id=self.source_asset_id,
-                    query=query, sort="{timestamp:+1}", limit=limit
+                    path=API_DATA_PATH,
+                    collection=col,
+                    asset_id=self.source_asset_id,
+                    query=query,
+                    sort="{timestamp:+1}",
+                    limit=limit,
                 )
 
                 count = res.count
@@ -299,15 +333,11 @@ class ToLocalTransfer(LoggingMixin):
                 records = res.data
 
                 data_str = json.dumps(records)
+                data_str = data_str.replace('"company_id": %s' % self.source_company_id, '"company_id": %s' % 1)
                 data_str = data_str.replace(
-                    "\"company_id\": %s" % self.source_company_id,
-                    "\"company_id\": %s" % 1
+                    '"asset_id": %s' % self.source_asset_id, '"asset_id": %s' % self.local_asset_id
                 )
-                data_str = data_str.replace(
-                    "\"asset_id\": %s" % self.source_asset_id,
-                    "\"asset_id\": %s" % self.local_asset_id
-                )
-                if col == 'wits':
+                if col == "wits":
                     for config_name, mapped_ids in self.config_id_mapper.items():
                         for id_source, id_local in mapped_ids.items():
                             data_str = data_str.replace(id_source, id_local)
@@ -315,14 +345,14 @@ class ToLocalTransfer(LoggingMixin):
                 records = json.loads(data_str)
 
                 for record in records:
-                    record.pop('_id', None)
+                    record.pop("_id", None)
 
                 res = self.local_api_worker.post(path=API_DATA_PATH, data=json.dumps(records))
 
-                pbar_added = round((records[-1]['timestamp'] - ts) / (end_timestamp - start_timestamp) * 100)
+                pbar_added = round((records[-1]["timestamp"] - ts) / (end_timestamp - start_timestamp) * 100)
                 pbar.update(pbar_added)
 
-                ts = records[-1]['timestamp']
+                ts = records[-1]["timestamp"]
 
             pbar.update(100 - pbar.n)
 
