@@ -1,10 +1,8 @@
-from typing import Union, List
-
-from worker.data.operations import get_data_by_path, get_config_by_id, compare_float
+from typing import List, Union
 
 from worker import API
+from worker.data.operations import compare_float, get_config_by_id, get_data_by_path
 from worker.exceptions import MissingConfigError
-
 from worker.wellbore.model.drillstring import Drillstring
 from worker.wellbore.model.enums import HoleType
 from worker.wellbore.model.hole import Hole
@@ -46,7 +44,7 @@ def run_drillstring_and_create_wellbore(wits: dict, mud_flow_in: float = None) -
     if not bit:
         raise MissingConfigError(f"Bit was not found in the drillstring with _id='{drillstring_id}'")
 
-    asset_id = wits['asset_id']
+    asset_id = wits["asset_id"]
     bit_size = bit.size
 
     bit_depth = get_data_by_path(wits, "data.bit_depth", float)
@@ -54,14 +52,18 @@ def run_drillstring_and_create_wellbore(wits: dict, mud_flow_in: float = None) -
 
     # setting cased-hole sections
     query = "{data.inner_diameter#gte#%s}" % bit_size
-    casings = api_worker.get(path="/v1/data/corva", collection="data.casing", asset_id=asset_id, query=query, limit=100).data
+    casings = api_worker.get(
+        path="/v1/data/corva", collection="data.casing", asset_id=asset_id, query=query, limit=100
+    ).data
     hole = set_casings(casings)
     smallest_cased_hole_diameter = hole.get_min_inner_diameter() or 100
 
     # ====== setting open-hole sections
     query = "{data.id#lte#%s}" % active_drillstring_number
     sort = "{data.id:1}"
-    drillstrings = api_worker.get(path="/v1/data/corva", collection="data.drillstring", asset_id=asset_id, query=query, sort=sort, limit=100).data
+    drillstrings = api_worker.get(
+        path="/v1/data/corva", collection="data.drillstring", asset_id=asset_id, query=query, sort=sort, limit=100
+    ).data
     hole = add_open_holes(hole, drillstrings, smallest_cased_hole_diameter, hole_depth)
 
     mud_flow_in = get_mud_flow_in(mud_flow_in, wits)
@@ -75,7 +77,9 @@ def run_drillstring_and_create_wellbore(wits: dict, mud_flow_in: float = None) -
     )
 
 
-def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None, is_design: bool = False) -> Union[Wellbore, None]:
+def run_casingstring_and_create_wellbore(
+    wits: dict, mud_flow_in: float = None, is_design: bool = False
+) -> Union[Wellbore, None]:
     """
     Get the wits record and create a wellbore
     :param wits: wits records in json format
@@ -109,35 +113,37 @@ def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None,
     # For best results in running a casing/liner in the well, the components should be presented.
     # If not we create an alternative.
     if not casing_components:
-        # If it is a casing that reaches to the surface, we can use the provided information on the top to construct a casing string.
+        # If it is a casing that reaches to the surface, we can use the provided
+        # information on the top to construct a casing string.
         casing_components = [
             {
                 "family": "casing_joints",
                 "linear_weight": casing_linear_weight,
                 "length": casing_bottom_depth - casing_top_depth,
                 "outer_diameter": casing_outer_diameter,
-                "inner_diameter": casing_inner_diameter
+                "inner_diameter": casing_inner_diameter,
             }
         ]
 
         # For liners, we use the top components for the casing joint part of the liner.
-        # From the surface to the liner hanger, we create the same component with the family of DP (it is not the actual casing part and will be removed later).
+        # From the surface to the liner hanger, we create the same component with
+        # the family of DP (it is not the actual casing part and will be removed later).
         if casing_top_depth > Wellbore.DEPTH_THRESHOLD:
             add_component = {
                 "family": "dp",
                 "linear_weight": casing_linear_weight,
                 "length": casing_top_depth,
                 "outer_diameter": casing_outer_diameter,
-                "inner_diameter": casing_inner_diameter
+                "inner_diameter": casing_inner_diameter,
             }
             casing_components.insert(0, add_component)
 
-        casingstring['data']['components'] = casing_components
+        casingstring["data"]["components"] = casing_components
 
     # setting active drillstring
     casingstring = Drillstring(casingstring)
 
-    asset_id = wits['asset_id']
+    asset_id = wits["asset_id"]
 
     bit_depth = get_data_by_path(wits, "data.bit_depth", float)
     hole_depth = get_data_by_path(wits, "data.hole_depth", float)
@@ -145,41 +151,23 @@ def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None,
     query = "{data.inner_diameter#gt#%s}" % casing_inner_diameter
     sort = "{data.inner_diameter:-1}"
     previous_casings = api_worker.get(
-        path="/v1/data/corva",
-        collection=casing_data_source,
-        asset_id=asset_id,
-        query=query,
-        sort=sort,
-        limit=100
+        path="/v1/data/corva", collection=casing_data_source, asset_id=asset_id, query=query, sort=sort, limit=100
     ).data
 
     drilling_data_source = "data.well-sections" if is_design else "data.drillstring"
     sort = "{data.diameter:-1}" if is_design else "{timestamp: -1}"
 
     drill_sections = api_worker.get(
-        path="/v1/data/corva",
-        collection=drilling_data_source,
-        asset_id=asset_id,
-        sort=sort,
-        limit=100
+        path="/v1/data/corva", collection=drilling_data_source, asset_id=asset_id, sort=sort, limit=100
     ).data
 
     # use data.well-sections to create hole
     if is_design:
-        hole = create_hole_using_well_sections_data(
-            previous_casings,
-            drill_sections,
-            casing_bottom_depth
-        )
+        hole = create_hole_using_well_sections_data(previous_casings, drill_sections, casing_bottom_depth)
 
     # use data.drillstring to create hole
     else:
-        hole = create_hole_use_drillstring_data(
-            previous_casings,
-            drill_sections,
-            casing_outer_diameter,
-            hole_depth
-        )
+        hole = create_hole_use_drillstring_data(previous_casings, drill_sections, casing_outer_diameter, hole_depth)
 
     mud_flow_in = get_mud_flow_in(mud_flow_in, wits)
 
@@ -192,24 +180,30 @@ def run_casingstring_and_create_wellbore(wits: dict, mud_flow_in: float = None,
     )
 
 
-def get_detailed_hole_from_elements(elements: List[dict],
-                                    previous_element_top_depth: float,
-                                    possible_top_depth: float,
-                                    extend_casing_to_top: bool,
-                                    is_riser: bool
-                                    ) -> Hole:
+def get_detailed_hole_from_elements(
+    elements: List[dict],
+    previous_element_top_depth: float,
+    possible_top_depth: float,
+    extend_casing_to_top: bool,
+    is_riser: bool,
+) -> Hole:
     """
     This function converts elements of casing/riser components into a Hole.
     :param elements: list casing/riser components
     :param previous_element_top_depth: will be used as the bottom depth of current component
-    :param possible_top_depth:  possible top depth to which a casing/riser can extend. In case of a casing, it will extend to the btm of riser (if available)
+    :param possible_top_depth:  possible top depth to which a casing/riser can extend.
+                                In case of a casing, it will extend to the btm of riser (if available)
     :param extend_casing_to_top: if the casing/riser should extend to the top
     :param is_riser: If its a riser or a cased hole
     :return: Hole with all the components as HoleSections
     """
     casing_hole: Hole = Hole()
 
-    elements = [element for index, element in enumerate(elements) if check_casing_element_validity(element, index, extend_casing_to_top)]
+    elements = [
+        element
+        for index, element in enumerate(elements)
+        if check_casing_element_validity(element, index, extend_casing_to_top)
+    ]
 
     for element in reversed(elements):
         element_id = element.get("inner_diameter", 0.0)
@@ -218,7 +212,9 @@ def get_detailed_hole_from_elements(elements: List[dict],
         element_top = element_bottom - element_length
 
         if element_top < possible_top_depth:
-            create_section_and_append(casing_hole, element_id, possible_top_depth, element_bottom, HoleType.CASED_HOLE, is_riser)
+            create_section_and_append(
+                casing_hole, element_id, possible_top_depth, element_bottom, HoleType.CASED_HOLE, is_riser
+            )
             break
 
         create_section_and_append(casing_hole, element_id, element_top, element_bottom, HoleType.CASED_HOLE, is_riser)
@@ -236,7 +232,9 @@ def get_detailed_hole_from_elements(elements: List[dict],
 
 
 def create_section_and_append(casing_hole, inner_diameter, top_depth, bottom_depth, hole_type, is_riser):
-    sec = HoleSection(inner_diameter=inner_diameter, top_depth=top_depth, bottom_depth=bottom_depth, hole_type=hole_type)
+    sec = HoleSection(
+        inner_diameter=inner_diameter, top_depth=top_depth, bottom_depth=bottom_depth, hole_type=hole_type
+    )
     if is_riser:
         sec = Riser(inner_diameter=inner_diameter, top_depth=top_depth, bottom_depth=bottom_depth, hole_type=hole_type)
 
@@ -257,20 +255,12 @@ def check_casing_element_validity(casing_element: dict, idx: int, extend_casing_
     if not element_family or not isinstance(element_family, str):
         return False
 
-    ignored_families = (
-        "dp",
-        "hwdp"
-    )
-
-    # A dp component in casing is considered invalid. It is ignored when setting casing
-    if element_family.lower() in ignored_families:
-        return False
-
-    # Ignoring casing components with length less than 20 feet and only components that are not top most or those that don't extend to top depth.
+    # Ignoring casing components with length less than 20 feet and only components
+    # that are not top most or those that don't extend to top depth.
     if element_length < 20.0 and (idx != 0 or not extend_casing_to_top):
         return False
-
-    return True
+    # Only accept the casing joints and riser components
+    return True if element_family in ["casing_joints", "riser"] else False
 
 
 def set_casings(casings: List[dict]) -> Hole:
@@ -283,21 +273,21 @@ def set_casings(casings: List[dict]) -> Hole:
         return Hole()
 
     possible_casing_top_depth: float = 0.0
-    riser = next((csg for csg in casings if csg.get('data', {}).get('is_riser', False)), {})
+    riser = next((csg for csg in casings if csg.get("data", {}).get("is_riser", False)), {})
 
     if riser:
         possible_casing_top_depth = riser.get("data").get("bottom_depth")
         casings.remove(riser)
 
     # sorting the casings in the ascending order (the smaller the inner_diameter the earlier it is added)
-    casings = sorted(casings, key=lambda csg: csg.get('data', {}).get('inner_diameter'))
+    casings = sorted(casings, key=lambda csg: csg.get("data", {}).get("inner_diameter"))
 
     # finding if a liner is overlapping outer liners
     # this is common in offshore drilling where they set the casings at the sea floor
     index = 1
     while index < len(casings):
-        top_depth_inner = casings[index - 1].get('data', {}).get('top_depth', 1000)
-        top_depth_outer = casings[index].get('data', {}).get('top_depth', 1000)
+        top_depth_inner = casings[index - 1].get("data", {}).get("top_depth", 1000)
+        top_depth_outer = casings[index].get("data", {}).get("top_depth", 1000)
         if top_depth_outer + Wellbore.DEPTH_THRESHOLD > top_depth_inner:
             casings.pop(index)
         else:
@@ -327,11 +317,14 @@ def set_casings(casings: List[dict]) -> Hole:
             casing_hole.sections.append(hole_section)
         else:
             previous_casing_element_top_depth = casing_bottom
-            # Individual casing elements have to be looped in reverse order to correctly account for the topmost element going to surface is not liner
+            # Individual casing elements have to be looped in reverse order to correctly account
+            # for the topmost element going to surface is not liner
             extend_casing_to_top: bool = False
             if index == 0:
                 extend_casing_to_top = True
-            casing_hole = get_detailed_hole_from_elements(casing_elements, previous_casing_element_top_depth, casing_top, extend_casing_to_top, False)
+            casing_hole = get_detailed_hole_from_elements(
+                casing_elements, previous_casing_element_top_depth, casing_top, extend_casing_to_top, False
+            )
 
         casing_holes.append(casing_hole)
 
@@ -339,13 +332,17 @@ def set_casings(casings: List[dict]) -> Hole:
     if riser:
         riser_elements: List[dict] = riser.get("data", {}).get("components", [])
         previous_riser_element_top_depth = possible_casing_top_depth
-        riser_hole: Hole = get_detailed_hole_from_elements(riser_elements, previous_riser_element_top_depth, 0.0, True, True)
+        riser_hole: Hole = get_detailed_hole_from_elements(
+            riser_elements, previous_riser_element_top_depth, 0.0, True, True
+        )
         casing_holes.insert(0, riser_hole)
 
     return Hole.merge_holes(casing_holes)
 
 
-def add_open_holes(hole: Hole, drillstrings: List[dict], smallest_cased_hole_diameter: float, hole_depth: float) -> Hole:
+def add_open_holes(
+    hole: Hole, drillstrings: List[dict], smallest_cased_hole_diameter: float, hole_depth: float
+) -> Hole:
     for ds in drillstrings:
         bit = Drillstring(ds).get_bit()
         if not bit:
@@ -359,10 +356,24 @@ def add_open_holes(hole: Hole, drillstrings: List[dict], smallest_cased_hole_dia
 
         start_depth = ds.get("data", {}).get("start_depth")
 
+        # if the open hole size increases then the prior open hole section IDs should be updated
+        for section in reversed(hole):
+            if section.hole_type == HoleType.OPEN_HOLE:
+                if section.inner_diameter < bit_size:
+                    section.inner_diameter = bit_size
+            else:
+                break
+
+        previous_open_hole_size = hole.get_open_hole()[-1].inner_diameter if len(hole.get_open_hole()) > 0 else None
+
+        # if the previous drillstring section inner diameter is equal to this bit size
+        # there is no need to add a new drillstring section
+        if previous_open_hole_size and previous_open_hole_size == bit_size:
+            continue
+
         # if due to the side track the hole depth reduced, then it should update the setting depths in the open hole
         hole.sections = [
-            sec for sec in hole.sections
-            if sec.hole_type != HoleType.OPEN_HOLE or sec.top_depth <= hole_depth
+            sec for sec in hole.sections if sec.hole_type != HoleType.OPEN_HOLE or sec.top_depth <= hole_depth
         ]
 
         # if a new open-hole section is created in addition to the previous one,
@@ -372,15 +383,15 @@ def add_open_holes(hole: Hole, drillstrings: List[dict], smallest_cased_hole_dia
         top_depth = hole.get_bottom_depth()
         bottom_depth = top_depth + 0.0001
         current_hole_section = HoleSection(
-            top_depth=top_depth,
-            bottom_depth=bottom_depth,
-            inner_diameter=bit_size,
-            hole_type=HoleType.OPEN_HOLE
+            top_depth=top_depth, bottom_depth=bottom_depth, inner_diameter=bit_size, hole_type=HoleType.OPEN_HOLE
         )
 
         if previous_hole_section:
             # The casing bottom depth can't be modified if the difference is more than 300 ft
-            cased_hole_condition = previous_hole_section.hole_type == HoleType.CASED_HOLE and start_depth - previous_hole_section.bottom_depth < 300
+            cased_hole_condition = (
+                previous_hole_section.hole_type == HoleType.CASED_HOLE
+                and start_depth - previous_hole_section.bottom_depth < 300
+            )
             if cased_hole_condition or previous_hole_section.hole_type == HoleType.OPEN_HOLE:
                 previous_hole_section.set_bottom_depth(start_depth)
                 previous_hole_section.set_length()
@@ -422,10 +433,7 @@ def get_mud_flow_in(mud_flow_in: Union[float, None], wits: dict) -> Union[float,
 
 
 def create_hole_use_drillstring_data(
-        previous_casings: List[dict],
-        drillstrings: List[dict],
-        casing_outer_diameter: float,
-        hole_depth: float
+    previous_casings: List[dict], drillstrings: List[dict], casing_outer_diameter: float, hole_depth: float
 ) -> Union[Hole, None]:
     """
     Create a hole using data.drillstring collection
@@ -436,7 +444,8 @@ def create_hole_use_drillstring_data(
     :return: a hole
     """
     drillstrings = [
-        string for string in drillstrings
+        string
+        for string in drillstrings
         if (string.get("data", {}).get("components", [{}])[-1].get("size") or -1) > casing_outer_diameter
     ]
 
@@ -447,9 +456,7 @@ def create_hole_use_drillstring_data(
 
 
 def create_hole_using_well_sections_data(
-        previous_casings: List[dict],
-        drill_sections: List[dict],
-        casing_bottom_depth: float
+    previous_casings: List[dict], drill_sections: List[dict], casing_bottom_depth: float
 ) -> Union[Hole, None]:
     """
     Create a hole using data.well-sections collection
@@ -472,12 +479,18 @@ def create_hole_using_well_sections_data(
         open_hole_bottom_depth = section_data.get("bottom_depth")
         open_hole_diameter = section_data.get("diameter")
 
-        if previous_casing_bottom_depth <= open_hole_top_depth <= open_hole_bottom_depth <= casing_bottom_depth + Wellbore.DEPTH_THRESHOLD:
+        if (
+            previous_casing_bottom_depth
+            <= open_hole_top_depth
+            <= open_hole_bottom_depth
+            <= casing_bottom_depth + Wellbore.DEPTH_THRESHOLD
+        ):
             open_hole = HoleSection(
                 inner_diameter=open_hole_diameter,
                 top_depth=open_hole_top_depth,
                 bottom_depth=open_hole_bottom_depth,
-                hole_type=HoleType.OPEN_HOLE)
+                hole_type=HoleType.OPEN_HOLE,
+            )
             hole.add_section(open_hole)
 
     return hole
