@@ -1,5 +1,5 @@
 from copy import deepcopy
-from typing import Union, List
+from typing import List, Union
 
 from worker.data.operations import get_data_by_path
 from worker.data.serialization import serialization
@@ -13,13 +13,11 @@ class Hole(SectionsMixin):
     DEPTH_THRESHOLD = 50  # ft
     LENGTH_THRESHOLD = 1  # ft
 
-    SERIALIZED_VARIABLES = {
-        'sections': list
-    }
+    SERIALIZED_VARIABLES = {"sections": list}
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.sections = kwargs.get('sections') or []
+        self.sections = kwargs.get("sections") or []
 
     def add_section(self, section: HoleSection):
         """
@@ -153,23 +151,25 @@ class Hole(SectionsMixin):
             return
 
         # sorting the casings in the ascending order (the smaller the inner_diameter the earlier it is added)
-        casings = sorted(casings, key=lambda csg: csg.get('data', {}).get('inner_diameter'))
+        casings = sorted(casings, key=lambda csg: csg.get("data", {}).get("inner_diameter"))
 
         # removing the outer casings at the surface
         surface_index = next(
             (
-                idx for idx, csg in enumerate(casings)
-                if csg.get('data', {}).get('top_depth', 1000) < Hole.DEPTH_THRESHOLD
-            ), 0
+                idx
+                for idx, csg in enumerate(casings)
+                if csg.get("data", {}).get("top_depth", 1000) < Hole.DEPTH_THRESHOLD
+            ),
+            0,
         )
-        casings = casings[0: surface_index + 1]
+        casings = casings[0 : surface_index + 1]
 
         # finding if a liner is overlapping outer liners
         # this is common in offshore drilling where they set the casings at the sea floor
         index = 1
         while index < len(casings):
-            top_depth_inner = casings[index - 1].get('data', {}).get('top_depth', 1000)
-            top_depth_outer = casings[index].get('data', {}).get('top_depth', 1000)
+            top_depth_inner = casings[index - 1].get("data", {}).get("top_depth", 1000)
+            top_depth_outer = casings[index].get("data", {}).get("top_depth", 1000)
             if top_depth_outer + Hole.DEPTH_THRESHOLD > top_depth_inner:
                 casings.pop(index)
             else:
@@ -179,10 +179,10 @@ class Hole(SectionsMixin):
         casings = reversed(casings)
 
         for csg in casings:
-            hole_section = HoleSection(**csg.get('data', {}), hole_type=HoleType.CASED_HOLE)
+            hole_section = HoleSection(**csg.get("data", {}), hole_type=HoleType.CASED_HOLE)
             self.add_section(hole_section)
 
-    def update_casings(self, casings: 'Hole'):
+    def update_casings(self, casings: "Hole"):
         """
         To remove the casings of the current hole and
         replace them with the given one
