@@ -1,11 +1,11 @@
-import simplejson as json
 from copy import deepcopy
 from typing import Union
 
+import simplejson as json
+
 from worker import API
 from worker.data.json_encoder import JsonEncoder
-from worker.data.operations import get_data_by_path, nanround, get_config_by_id, is_stream_app
-
+from worker.data.operations import get_config_by_id, get_data_by_path, is_stream_app, nanround
 from worker.data.serialization import serialization
 from worker.mixins.logging import Logger
 from worker.wellbore.model.annulus import Annulus
@@ -21,13 +21,13 @@ class Wellbore:
     DEPTH_THRESHOLD = 50  # ft
 
     SERIALIZED_VARIABLES = {
-        'original_drillstring': Drillstring,
-        'original_hole': Hole,
-        'bit_depth': float,
-        'hole_depth': float,
-        'last_hole_depth': float,
-        'last_non_decreasing_hole_depth': float,
-        'under_reamer_alert_timestamp': float
+        "original_drillstring": Drillstring,
+        "original_hole": Hole,
+        "bit_depth": float,
+        "hole_depth": float,
+        "last_hole_depth": float,
+        "last_non_decreasing_hole_depth": float,
+        "under_reamer_alert_timestamp": float,
     }
 
     def __init__(self, **kwargs):
@@ -36,20 +36,24 @@ class Wellbore:
         self.under_reamer: Union[UnderReamer, None] = None
         self.under_reamer_alert_timestamp: float = 0.0
 
-        self.original_drillstring: Drillstring = kwargs.get('original_drillstring') or kwargs.get('drillstring')
-        self.actual_drillstring: Drillstring = kwargs.get('actual_drillstring')
+        self.original_drillstring: Drillstring = kwargs.get("original_drillstring") or kwargs.get("drillstring")
+        self.actual_drillstring: Drillstring = kwargs.get("actual_drillstring")
 
         # Explicitly checking if original_hole is not None, because bool of Hole with no sections evaluates to False
-        self.original_hole: Hole = kwargs.get('original_hole') if kwargs.get('original_hole') is not None else kwargs.get('hole')
-        self.actual_hole: Hole = kwargs.get('actual_hole')
+        self.original_hole: Hole = (
+            kwargs.get("original_hole") if kwargs.get("original_hole") is not None else kwargs.get("hole")
+        )
+        self.actual_hole: Hole = kwargs.get("actual_hole")
 
-        self.actual_annulus: Annulus = kwargs.get('actual_annulus')
+        self.actual_annulus: Annulus = kwargs.get("actual_annulus")
 
-        self.bit_depth: float = kwargs.get('bit_depth') or 0.0
-        self.hole_depth: float = kwargs.get('hole_depth')
+        self.bit_depth: float = kwargs.get("bit_depth") or 0.0
+        self.hole_depth: float = kwargs.get("hole_depth")
 
-        self.last_hole_depth: float = kwargs.get('last_hole_depth') or self.hole_depth
-        self.last_non_decreasing_hole_depth: float = kwargs.get('last_non_decreasing_hole_depth') or self.last_hole_depth
+        self.last_hole_depth: float = kwargs.get("last_hole_depth") or self.hole_depth
+        self.last_non_decreasing_hole_depth: float = (
+            kwargs.get("last_non_decreasing_hole_depth") or self.last_hole_depth
+        )
 
         mud_flow_in = kwargs.get("mud_flow_in") or 0.0
 
@@ -106,7 +110,9 @@ class Wellbore:
         self.last_hole_depth = self.hole_depth
 
     def add_under_reamer_sections(self, mud_flow_rate):
-        current_hole: HoleSection = self.actual_hole.find_section_at_measured_depth(self.under_reamer.top_depth + 0.0001)
+        current_hole: HoleSection = self.actual_hole.find_section_at_measured_depth(
+            self.under_reamer.top_depth + 0.0001
+        )
 
         # Determine a valid start of reaming depth: either casing shoe or open hole top depth.
         if current_hole.hole_type == HoleType.CASED_HOLE:
@@ -116,15 +122,19 @@ class Wellbore:
         else:
             return
 
-        activation_mode = self.under_reamer.activate_under_reamer(mud_flow_rate, start_reaming_depth, current_hole.hole_type)
+        activation_mode = self.under_reamer.activate_under_reamer(
+            mud_flow_rate, start_reaming_depth, current_hole.hole_type
+        )
 
         # If unactivated, do nothing
         if activation_mode == self.under_reamer.UnderReamerActivationType.UNACTIVATED:
             return
 
         # Activated for the first time
-        if activation_mode == self.under_reamer.UnderReamerActivationType.MUD_FLOW_RATE or \
-                activation_mode == self.under_reamer.UnderReamerActivationType.OPEN_HOLE:
+        if (
+            activation_mode == self.under_reamer.UnderReamerActivationType.MUD_FLOW_RATE
+            or activation_mode == self.under_reamer.UnderReamerActivationType.OPEN_HOLE
+        ):
             drillstring = self.get_and_update_drill_string()
 
             # Update the original drillstring to match the chopped drillstring under-reamer component
@@ -139,8 +149,11 @@ class Wellbore:
 
                 Logger.debug(f"Updated API with under-reamer activation at depth {self.under_reamer.ur_opened_depth}")
             else:
-                Logger.info(f"Under-reamer was opened at {self.under_reamer.ur_opened_depth }. "
-                            f"However, not updating the ur_opened_depth on drillstring on api because it was not triggered from Stream app")
+                Logger.info(
+                    f"Under-reamer was opened at {self.under_reamer.ur_opened_depth }. "
+                    f"However, not updating the ur_opened_depth on drillstring on api "
+                    f"because it was not triggered from Stream app"
+                )
 
         reamed_length = self.under_reamer.bottom_depth - self.under_reamer.ur_opened_depth
         # If under reamer is shallower than the opened depth do nothing
@@ -166,7 +179,9 @@ class Wellbore:
         bottom_hole.set_top_depth(self.under_reamer.ur_opened_depth)
         bottom_hole.set_length()
 
-        under_reamer_hole = HoleSection(inner_diameter=ur_opened_od, hole_type=HoleType.OPEN_HOLE, top_depth=0.0, bottom_depth=0, length=0)
+        under_reamer_hole = HoleSection(
+            inner_diameter=ur_opened_od, hole_type=HoleType.OPEN_HOLE, top_depth=0.0, bottom_depth=0, length=0
+        )
         under_reamer_hole.set_length(reamed_length)
 
         # If the current hole is zero no need to add a new enlarged section, enlarge the current hole
@@ -264,9 +279,11 @@ class Wellbore:
         return outside_volume_to - outside_volume_from
 
     def __repr__(self):
-        return f"Wellbore:\n" \
-               f"===Bit Depth / Hole Depth = {nanround(self.bit_depth)} / {nanround(self.hole_depth)}\n" \
-               f"===Drillstring:\n{self.actual_drillstring}\n" \
-               f"===Hole:\n{self.actual_hole}\n" \
-               f"===Annulus:\n{self.actual_annulus}\n\n" \
-               f"===Given Drillstring:\n{self.actual_drillstring}\n"
+        return (
+            f"Wellbore:\n"
+            f"===Bit Depth / Hole Depth = {nanround(self.bit_depth)} / {nanround(self.hole_depth)}\n"
+            f"===Drillstring:\n{self.actual_drillstring}\n"
+            f"===Hole:\n{self.actual_hole}\n"
+            f"===Annulus:\n{self.actual_annulus}\n\n"
+            f"===Given Drillstring:\n{self.actual_drillstring}\n"
+        )
